@@ -1,11 +1,10 @@
 /*-------------------------------------------------------------------------
  *
  * scansup.c
- *	  support routines for the lex/flex scanner, used by both the normal
- * backend as well as the bootstrap backend
+ *	  scanner support routines used by the core lexer
  *
- * Portions Copyright (c) 1996-2019, PgPool Global Development Group
- * Portions Copyright (c) 1996-2019, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2022, PgPool Global Development Group
+ * Portions Copyright (c) 1996-2022, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  *
@@ -20,102 +19,10 @@
 #include <ctype.h>
 #include <string.h>
 
-#include "scansup.h"
 #include "pg_wchar.h"
+#include "scansup.h"
 
 
-/* ----------------
- *		scanstr
- *
- * if the string passed in has escaped codes, map the escape codes to actual
- * chars
- *
- * the string returned is palloc'd and should eventually be pfree'd by the
- * caller!
- * ----------------
- */
-
-char *
-scanstr(const char *s)
-{
-	char	   *newStr;
-	int			len,
-				i,
-				j;
-
-	if (s == NULL || s[0] == '\0')
-		return pstrdup("");
-
-	len = strlen(s);
-
-	newStr = palloc(len + 1);	/* string cannot get longer */
-
-	for (i = 0, j = 0; i < len; i++)
-	{
-		if (s[i] == '\'')
-		{
-			/*
-			 * Note: if scanner is working right, unescaped quotes can only
-			 * appear in pairs, so there should be another character.
-			 */
-			i++;
-			/* The bootstrap parser is not as smart, so check here. */
-			Assert(s[i] == '\'');
-			newStr[j] = s[i];
-		}
-		else if (s[i] == '\\')
-		{
-			i++;
-			switch (s[i])
-			{
-				case 'b':
-					newStr[j] = '\b';
-					break;
-				case 'f':
-					newStr[j] = '\f';
-					break;
-				case 'n':
-					newStr[j] = '\n';
-					break;
-				case 'r':
-					newStr[j] = '\r';
-					break;
-				case 't':
-					newStr[j] = '\t';
-					break;
-				case '0':
-				case '1':
-				case '2':
-				case '3':
-				case '4':
-				case '5':
-				case '6':
-				case '7':
-					{
-						int			k;
-						long		octVal = 0;
-
-						for (k = 0;
-							 s[i + k] >= '0' && s[i + k] <= '7' && k < 3;
-							 k++)
-							octVal = (octVal << 3) + (s[i + k] - '0');
-						i += k - 1;
-						newStr[j] = ((char) octVal);
-					}
-					break;
-				default:
-					newStr[j] = s[i];
-					break;
-			}					/* switch */
-		}						/* s[i] == '\\' */
-		else
-			newStr[j] = s[i];
-		j++;
-	}
-	newStr[j] = '\0';
-	return newStr;
-}
-
 
 /*
  * downcase_truncate_identifier() --- do appropriate downcasing and
@@ -194,20 +101,10 @@ truncate_identifier(char *ident, int len, bool warn)
 	{
 		len = pg_mbcliplen(ident, len, NAMEDATALEN - 1);
 		if (warn)
-		{
-			/*
-			 * We avoid using %.*s here because it can misbehave if the data
-			 * is not valid in what libc thinks is the prevailing encoding.
-			 */
-			char		buf[NAMEDATALEN];
-
-			memcpy(buf, ident, len);
-			buf[len] = '\0';
 			ereport(NOTICE,
 					(errcode(ERRCODE_NAME_TOO_LONG),
-					 errmsg("identifier \"%s\" will be truncated to \"%s\"",
-							ident, buf)));
-		}
+					 errmsg("identifier \"%s\" will be truncated to \"%.*s\"",
+							ident, len, ident)));
 		ident[len] = '\0';
 	}
 #endif
